Callback

Struct Callback 

pub struct Callback<'a, const D: usize, P> {
    pub event: &'a dyn Fn(f64, SVector<f64, D>, &P) -> f64,
    pub effect: &'a dyn Fn(&mut ODE<'_, D, P>),
}
A function that takes in a time and a state and outputs a single float value

The integration solver will check this function for zero crossings

Fields

event: &'a dyn Fn(f64, SVector<f64, D>, &P) -> f64

The function to check for zero crossings

effect: &'a dyn Fn(&mut ODE<'_, D, P>)

The function to change the ODE